heatmap_calendar_plus library

Classes

HeatMap
HeatMapCalendar
HeatMapCalendarController
HeatMapCellStyle
Defines the visual style applied to an individual heatmap cell.

Enums

ColorMode
HeatmapCalendarType
The type of calendar view to display.

Typedefs

HeaderBuilder = Widget Function(BuildContext context, DateTime? currentDate)
HeatMapCellStyleResolver = HeatMapCellStyle? Function(DateTime date)
A callback that resolves the style of a single heatmap cell by its date.